import { select, json, tree, hierarchy, linkHorizontal } from 'd3';

const svg = select('svg').attr('transform', `translate(10, 0)`);
const trees = svg.append('g');
const crumbs = svg.append('g');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

let breadCrumbs;
let treeLayout = tree().size([width-800, height-60])

svg
  .attr('width', width)
  .attr('height', height)

const renderBreadCrumbs = () => {
  let crumbs = '';
  breadCrumbs.forEach(crumb => {
      crumbs = crumbs + `${crumb}  /  `;
  });
  
  trees.selectAll('text').remove();
  trees.selectAll('g').data([null])
    .enter().append('text')
      .attr('x', 60)
      .attr('y', 600)
      .text(crumbs);
}

const setBreadCrumbs = data => {
  breadCrumbs = [];
  while(data.parent) {
    breadCrumbs.push(data.data.data.CT);
    data = data.parent;
  }
  
  breadCrumbs = breadCrumbs.reverse();
  renderBreadCrumbs();
}


json('data.json')
  .then(data => {
  
    data.forEach((window, index) => {
      
      const root = hierarchy(window);
      const links = treeLayout(root).links();
      const linkPathGenerator = linkHorizontal()
        .x(d => d.y)
        .y(d => d.x);
      
      const g = svg.append('g').attr('transform', `translate(0, ${index * 200})`);
      
      g.selectAll(`.window-${index}`).data(links)
        .enter().append('path')
          .attr('class', `window-${index}`)
          .attr('d', linkPathGenerator)
          .attr('transform', `translate(0, 0)`);
      
      const textG = g.selectAll('text').data(root.descendants());
      textG
        .enter().append('text')
          .attr('class', `window-text-${index}`)
          .attr('x', d => d.y)
          .attr('y', d => d.x)
          .attr('dy', '0.32em')
          .text(d => d.data.data.CT)
          .on('mouseover', d => setBreadCrumbs(d));
    });
  });